function [height,width] = plotLowerLevelOfGSIPImplicitly2D( obj,hsp, indexOfLowLev,x,lb,ub,varargin )

set(hsp,'Units','centimeter');
oldPos=get(hsp,'Position');
maxwidth=oldPos(3);
maxheight=oldPos(4);
%set the position and size of the subplot
y1Range = lb(1)-ub(1);
y2Range = lb(2)-ub(2);

width = maxwidth;
height = y2Range/y1Range*width;

if height>maxheight
   height=maxheight; 
   width=y1Range/y2Range*height; 
end


set(hsp,'Position',[oldPos(1),oldPos(2),width,height]);



%Find semi-infinite constraints that belong to the given indexsets
indicesOfSemiInfConstrs=zeros(1,0);
for i=1:obj.getNrSemiInfConstrs
     index=obj.getIndexSetOfSemiInfConstr(i);
     if any(index==indexOfLowLev)
         indicesOfSemiInfConstrs=[indicesOfSemiInfConstrs,i];
     end
end

%plot the semi-infinite constraints

hold(hsp,'on');
h=ezplot(hsp,@(y1,y2) maxOfSemiInfConstrs(y1,y2),[lb(1),ub(1),lb(2),ub(2)]);
set(h,'color',[0,0,1]);


%plot the lower level constraints
hold(hsp,'on');
h=ezplot(hsp,@(y1,y2) maxOfIndexSet(y1,y2),[lb(1),ub(1),lb(2),ub(2)]);
set(h,'color','g');

%plot the points given in yred and yblue

nrPoints=(nargin-6)/2;
for k=1:nrPoints
    Y=varargin{2*k-1};
    color=varargin{2*k};
    if size(Y,1)~=0
    scatter(hsp,Y(:,1),Y(:,2),'MarkerEdgeColor','black','MarkerFaceColor',color)
    end
end

%settings for plot
 grid(hsp,'on');
 set(hsp, 'DataAspectRatio', [1 1 1]);
 set(hsp, 'Units', 'centimeters');
 xlim(hsp,[lb(1), ub(1)]);
 ylim(hsp,[lb(2), ub(2)]);
 ylabel(hsp,'y2');
 xlabel(hsp,'y1');
 title(hsp,sprintf('Containment condition of the indexset %i',indexOfLowLev));



    function g=maxOfSemiInfConstrs(y1,y2)
        g=-inf;
        for i=indicesOfSemiInfConstrs
            g=max(g,obj.evalSemiInfConstrs(i,x,[y1,y2]));
        end
        %bounds from box
        g=max(g,lb(1)-y1); 
        g=max(g,y1-ub(1));
        g=max(g,lb(2)-y2); 
        g=max(g,y2-ub(2));
    end
    function u=maxOfIndexSet(y1,y2)
        u=-inf;
        %collect non linear constraints
        if obj.getNrNonlinLowLevConstrs(indexOfLowLev)>0
            u_temp=obj.evalLowLevNonlinConstrs(indexOfLowLev,x,[y1,y2]);
            assert(size(u_temp,1)==size(y1,1));
            for i=1:obj.getNrNonlinLowLevConstrs(indexOfLowLev)            
                u=max(u,u_temp(:,i));          
            end
        end
        
        %collect bounds
        [problb,probub]=obj.getBoundsOnLowLevVars(indexOfLowLev,x);
        u=max(u,problb(1)-y1); 
        u=max(u,y1-probub(1));
        u=max(u,problb(2)-y2); 
        u=max(u,y2-probub(2));
        %bounds from box
        %Add small term to the bounds to get a better picture, i. e. cann
        %see both lines
        u=max(u,lb(1)+0.005*(ub(1)-lb(1))-y1); 
        u=max(u,y1-ub(1)+0.005*(ub(1)-lb(1)));
        u=max(u,lb(2)+0.005*(ub(2)-lb(2))-y2); 
        u=max(u,y2-ub(2)+0.005*(ub(2)-lb(2)));
        %collect linear constraints
        [A,b]=obj.getLinIneqsOnLowLevVars(indexOfLowLev,x);
        for i=1:size(A,1)
            u=max(u,[y1,y2]*A(i,:)'-b(i));
        end
        
    end


end
