function [height,width] = plotLowerLevelOfGSIPImplicitly2D2( obj,hsp,indexOfLowLev,x,lb,ub,varargin )


%Global settings
NrOfPointsInDir=500;


%extract the current size of the subplot
set(hsp,'Units','centimeter');
oldPos=get(hsp,'Position');
maxwidth=oldPos(3);
maxheight=oldPos(4);
%set the position and size of the subplot
y1Range = lb(1)-ub(1);
y2Range = lb(2)-ub(2);

width = maxwidth;
height = y2Range/y1Range*width;

if height>maxheight
   height=maxheight; 
   width=y1Range/y2Range*height; 
end


set(hsp,'Position',[oldPos(1),oldPos(2),width,height]);


hold(hsp,'on');


%compute x data
y1_temp=linspace(lb(1),ub(1),NrOfPointsInDir);
y2_temp=linspace(lb(2),ub(2),NrOfPointsInDir);

[y1_temp,y2_temp]=meshgrid(y1_temp,y2_temp);

y1=reshape(y1_temp,NrOfPointsInDir^2,1);
y2=reshape(y2_temp,NrOfPointsInDir^2,1);


%Find semi-infinite constraints that belong to the given indexsets
indicesOfSemiInfConstrs=zeros(1,0);
for i=1:obj.getNrSemiInfConstrs
     index=obj.getIndexSetOfSemiInfConstr(i);
     if any(index==indexOfLowLev)
         indicesOfSemiInfConstrs=[indicesOfSemiInfConstrs,i];
     end
end



%%plot the semi-infinite constraints
%evaluate the semi infinite constraints
g=maxOfSemiInfConstrs(y1,y2);
%transform vectors into matrix form:
y1=reshape(y1,NrOfPointsInDir,NrOfPointsInDir);
y2=reshape(y2,NrOfPointsInDir,NrOfPointsInDir);
g=reshape(g,NrOfPointsInDir,NrOfPointsInDir);
gPosNeg=g>0;
o=ones(NrOfPointsInDir);
Z=zeros(NrOfPointsInDir);
Z(~gPosNeg)=1*o(~gPosNeg);
contourf(hsp,y1,y2,Z,[1,1]);


%plot the lower level constraints
y1=reshape(y1_temp,NrOfPointsInDir^2,1);
y2=reshape(y2_temp,NrOfPointsInDir^2,1);

%%plot the IndexSet
%evaluate the constraints describing the indexset
u=maxOfIndexSet(y1,y2);
%transform vectors into matrix form:
y1=reshape(y1,NrOfPointsInDir,NrOfPointsInDir);
y2=reshape(y2,NrOfPointsInDir,NrOfPointsInDir);
u=reshape(u,NrOfPointsInDir,NrOfPointsInDir);
uPosNeg=u>0;
o=ones(NrOfPointsInDir);
Z=zeros(NrOfPointsInDir);
Z(~uPosNeg)=2*o(~uPosNeg);

contourf(hsp,y1,y2,Z,[2,2]);

%Set the colormap to get the right fillings
cmap=[135/255, 206/255, 250/255;0,1,0];
set(get(hsp,'parent'),'colormap',cmap)




%%plot the points given in yred and yblue
nrPoints=(nargin-6)/2;
for k=1:nrPoints
    Y=varargin{2*k-1};
    color=varargin{2*k};
    if size(Y,1)~=0
    scatter(hsp,Y(:,1),Y(:,2),'MarkerEdgeColor','black','MarkerFaceColor',color)
    end
end


%settings for plot
 grid(hsp,'on');
 set(hsp, 'DataAspectRatio', [1 1 1]);
 set(hsp, 'Units', 'centimeters');
 ylabel(hsp,'y2');
 xlabel(hsp,'y1')
 xlim(hsp,[lb(1), ub(1)]);
 ylim(hsp,[lb(2), ub(2)]);
 title(hsp,sprintf('Containment condition of the indexset %i',indexOfLowLev));




    function g=maxOfSemiInfConstrs(y1,y2)
        
        try
        g=-inf;
        for i=indicesOfSemiInfConstrs
            g=max(g,obj.evalSemiInfConstrs(i,x,[y1,y2]));
        end
        catch me
            warning('warning failed to evaluate on array inputs.')
            g=-inf*ones(NrOfPointsInDir^2,1);
            for j=1:NrOfPointsInDir^2
                for i=indicesOfSemiInfConstrs
                    g(j)=max(g(j),obj.evalSemiInfConstrs(i,x,[y1(j),y2(j)]));
                end
            end
        end
     end
    function u=maxOfIndexSet(y1,y2)       
        try 
            u=-inf;
            %collect non linear constraints
            if obj.getNrNonlinLowLevConstrs(indexOfLowLev)>0
                u_temp=obj.evalLowLevNonlinConstrs(indexOfLowLev,x,[y1,y2]);
                assert(size(u_temp,1)==size(y1,1));
                for i=1:obj.getNrNonlinLowLevConstrs(indexOfLowLev)            
                    u=max(u,u_temp(:,i));          
                end
            end
            %collect bounds
            [problb,probub]=obj.getBoundsOnLowLevVars(indexOfLowLev,x);
            u=max(u,problb(1)-y1); 
            u=max(u,y1-probub(1));
            u=max(u,problb(2)-y2); 
            u=max(u,y2-probub(2));
            [A,b]=obj.getLinIneqsOnLowLevVars(indexOfLowLev,x);
            for i=1:size(A,1)
                u=max(u,[y1,y2]*A(i,:)'-b(i));
            end
        catch me
            warning('warning failed to evaluate on array inputs.')
            u=-inf*ones(NrOfPointsInDir^2,1);
            for j=1:NrOfPointsInDir^2
                if obj.getNrNonlinLowLevConstrs(indexOfLowLev)>0
                    u_temp=obj.evalLowLevNonlinConstrs(indexOfLowLev,x,[y1(j),y2(j)]);
                    for i=1:obj.getNrNonlinLowLevConstrs(indexOfLowLev)            
                        u(j)=max(u(j),u_temp(:,i));          
                    end
                end

                %collect bounds
                [problb,probub]=obj.getBoundsOnLowLevVars(indexOfLowLev,x);
                u(j)=max(u(j),problb(1)-y1(j)); 
                u(j)=max(u(j),y1(j)-probub(1));
                u(j)=max(u(j),problb(2)-y2(j)); 
                u(j)=max(u(j),y2(j)-probub(2));
                [A,b]=obj.getLinIneqsOnLowLevVars(indexOfLowLev,x);
                for i=1:size(A,1)
                    u(j)=max(u(j),[y1(j),y2(j)]*A(i,:)'-b(i));
                end
                
            end
            
        end
        
    end
end