classdef ContainerConcTriangleWithGap < Container
    %C=ContainerConcTriangleWithGap() creates an instance of the container C given by:
    %
    %       C={ y in R^2 with:
    %               -y1-y2^2 <= 0
    %               -y1-1 <= 0
    %               0.25y1+y2-0.75 <= 0
    %               -(y1-2)^2 - (y2+0.5)^2 + 0.0625 <= 0
    %
    %   Bounding box: [-1,7]x[-1,1]
    
    properties (GetAccess=protected)
        dim =2;                             
        nrOfConstFuns=4;                    
        BoundingBox=[-1,-1;7,1]

    end
    

    
    
    methods
        %container functions
        function g=evalDescrFuns(~,i,y)   
            m=size(y,1);
            o=ones(m,1);
            switch i
                case 1
                    g=-y(:,1)-y(:,2).^2;
                case 2
                    g=1/4*y(:,1)+y(:,2)-3/4*o;
                case 3
                    g=-y(:,2)-o;
                case 4
                    
                    g=-(y(:,1)-2*o).^2-(y(:,2)+0.5*o).^2+1/16*o;                  
            end

        end
        %derivative
        function Dy_g=DyDescrFuns(~,i,y) 
            m=size(y,1);
            o=ones(m,1);
            z=zeros(m,1);
            switch i
                case 1
                    Dy_g=[-o,-2*y(:,2)];
                case 2
                    Dy_g=[1/4*o,o];
                case 3
                    Dy_g=[z,-o];
                case 4
                    Dy_g=[-2*(y(:,1)-2*o),-2*(y(:,2)+0.5*o)];
                
            end
        end
    end
    
    methods
        function plotContainer(obj)
            X = [7; ... %vertex
                -1; -0.81; -0.64; -0.49; -0.36; -0.25; -0.16; -0.09; -0.04; -0.01; 0; ...
                -0.01; -0.04; -0.09; -0.16; -0.25; -0.36; -0.49; -0.64; -0.81;... %parabola
                -1]; %vertex
            Y = [-1; ...        %vertex
                -1; -0.9; -0.8; -0.7; -0.6; -0.5; -0.4; -0.3; -0.2; -0.1; 0; ...
                0.1; 0.2; 0.3; 0.4; 0.5; 0.6; 0.7; 0.8; 0.9;... %parabola
                1];     %vertex
   
            ph = fill(X, Y, [135/255, 206/255, 250/255]); % sky blue
            set(ph, 'EdgeColor', 'blue');
            hold on;
            
            t = 0:pi/180:2*pi;
            o = ones(size(t));

            y1 = 2*o+0.25*cos(t);
            y2 = -0.5*o+0.25*sin(t);

            ph=fill(y1,y2,'white');
            set(ph, 'EdgeColor', 'blue');
            hold on;
        end
    end    
    
    
end

