classdef ContainerPyramid < Container
    %C=ContainerPyramid(n) creates an instance of the container C given by:
    %
    %       C={ y in R^n with:
    %               -yi <= 0 for i=1,...,n  
    %               sum_i=1^n(yi)-n <= 0}
    % 
    %   Bounding box: [0,n]^n


    properties (GetAccess=protected)
        dim                                 
        nrOfConstFuns                       
        BoundingBox

    end
    
    methods
        function p=ContainerPyramid(dim)
            p.dim=dim;
            p.nrOfConstFuns=dim+1;
            p.BoundingBox=[zeros(1,dim);dim*ones(1,dim)];

        end
    end
    
    methods
        %container functions
        function g=evalDescrFuns(obj,i,y)   
            m=size(y,1);

            switch i
                case obj.dim+1
                    g=sum(y,2)-obj.dim;
                otherwise
                    g=-y(:,i);
            end
        end
         %derivative
        function Dy_g=DyDescrFuns(obj,i,y)  
            m=size(y,1);
            
            switch i
                case obj.dim+1
                    Dy_g=ones(m,obj.dim);
                otherwise
                    Dy_g=zeros(m,obj.dim);
                    Dy_g(:,i)=-ones(m,1);             
            end
        end
    end
    
    methods
        function plotContainer(obj)
            switch obj.dim
                case 2
                    X = [0; ... %vertex
                        2; ... %vertex
                        0]; %vertex
                    Y = [0; ...        %vertex
                        0;... %vertex
                        2];     %vertex

                    ph = fill(X, Y, [135/255, 206/255, 250/255]); % sky blue
                    set(ph, 'EdgeColor', 'blue');
                    hold on;
                case 3
                    fill3([0,0,3],[0,3,0],[3,0,0],'blue', 'facealpha', 0.25); 
                    hold on            
                    fill3([0,0,3],[0,3,0],[0,0,0],'blue', 'facealpha', 0.25);
                    fill3([0,0,3],[0,0,0],[3,0,0],'blue', 'facealpha', 0.25);
                    fill3([0,0,0],[0,3,0],[3,0,0],'blue', 'facealpha', 0.25);
            end
        end
    end
    
    
end