

classdef DesignNonRotEllipse <Design
    %D=DesignNonRotEllips creates an instance of a design D(x) given by:
    %
    %       D(x)={ y in R^2 with:
    %               (y1-x1)^2/x3^2 + (y2-x2)^2/x4^2 - 1<= 0}
    %       
    %       Vol(x)=pi*x3*x4
    %
    %       x in X = { x in R^4 with
    %               10^-6 <= x3
    %               10^-6 <= x4}  

    properties (GetAccess=protected) 
      
        dim =2;                         
        nrOfParams=4;                   
        nrOfDesignConstrs=1;             
        initValsParams=[1,1,1,1];   
        
        linEqParamConstrs=[];            
        linIneqParamConstrs=[];          
        boundsOnParams =[-inf,-inf,1e-6,1e-6;inf,inf,inf,inf]
        
        nrOfNonlinParamIneqConstrs=0;    
        nrOfNonlinParamEqConstrs=0;      
        
        
        
        
        
        
        
        
              
    end
    methods
        %volume
        function v=vol(~,x)                
            v=pi*x(3)*x(4);
        end
        function grad_v=gradVol(~,x)
           grad_v=[0;0;pi*x(4);pi*x(3)]; 
        end
        
        %design functions
        function u=evalNonlinDescrFuns(~,x,y)   
           u=((y(1)-x(1))/x(3))^2+((y(2)-x(2))/x(4))^2-1; 
        end
        function Dy_u=DyNonlinDescrFuns(~,x,y)  
            Dy_u=[2/(x(3)^2)*(y(1)-x(1)), 2/(x(4)^2)*(y(2)-x(2))];
        end
        function Dx_u=DxNonlinDescrFuns(~,x,y)
            Dx_u=[-2/(x(3)^2)*(y(1)-x(1)),-2/(x(4)^2)*(y(2)-x(2)),-2*(x(3)^-3)*(y(1)-x(1))^2,-2*(x(4)^-3)*(y(2)-x(2))^2];
        end
  
        %Interior point
        function y=getInteriorPoint(~,x)      
            y=[x(1),x(2)];
        end
        function Dx_y=DxInnerPoint(~,~)
            Dx_y=[eye(2),zeros(2,2)];
        end
        
        %bounding box
        function [lb,ub]=getBoundingBox(~,x) 
            lb=[x(1)-x(3),x(2)-x(4)];
            ub=[x(1)+x(3),x(2)+x(4)];
        end
       
        function [lb,ub]=getBox(obj)
            lb=[0,0];
            ub=[2*pi, 1];
        end
        
    end
       
    %transformation 
    methods
        function y=evalTrafoFun(obj,x,z)
            y=[x(1)+z(:,2).*x(3).*cos(z(:,1)), x(2)+z(:,2).*x(4).*sin(z(:,1))];
        end
        function z=evalInvTrafoFun(obj,x,y)
            [THETA,RHO] = cart2pol((y(:,1)-x(1))/x(3),(y(:,2)-x(2))/x(4));
                z = [THETA,RHO];
        end
        function Dx_y=DxTrafoFun(obj,x,z)
            m = size(z,1);
            o = ones(m,1);
            Dx_y = zeros(2,4,m);
            Dx_y(1,1,:) = o;
            Dx_y(2,2,:) = o;
            Dx_y(1,3,:) = z(:,2).*cos(z(:,1));
            Dx_y(2,4,:) = z(:,2).*sin(z(:,1));
        end
    end
    
    methods
        function []=plotDesign(obj,x)
            t = 0:pi/180:2*pi;
            o = ones(size(t));

            y1 = x(1)*o+x(3)*cos(t);
            y2 = x(2)*o+x(4)*sin(t);

            fill(y1,y2,'green');
            hold on;
        end
    end
        
end