classdef NameOfTheDesign<Design %has to be the same as the filename
    % Template for the implementation of a design
    % x is allways a 1xm vector and y is normally a 1xn vector
    properties (GetAccess= protected)
        dim=1;                          %dimension of the design
        
        nrOfParams  =1;                 %number of parameters describing the design 
        
        nrOfDesignConstrs  =1;          %number of non-linear constaints describing the design  
        
        initValsParams=[0];             %initial values of the parameters    
        
        boundsOnParams=[-inf;inf];      %bounds on the parameters. First row 
                                        %is a 1xm dimensional vector of size 1xn
                                        %containing the lower bounds. The second 
                                        %row contains the upper bounds.
                                        
        linEqParamConstrs=[];           %linear equality constraints on
                                        %parameters of the form [A,b] for Ax=b.              
        linIneqParamConstrs=[];         %linear inequality constraints on
                                        %parameters of the form [A,b] for Ax<=b                    
        
        nrOfNonlinParamIneqConstrs=0;   %number of non-linear inequality constraints 
                                        %on the parameters
        nrOfNonlinParamEqConstrs=0;     %number of non-linear equality constraints
                                        %on the parameters                 
                     

       
    end
    
    methods
        
        %v=vol(x) returns the volume of the design.     
        function v=vol(obj,x)    
            v=0;
        end
        
        %y=getInteriorPoint(x) returns a point that lies in the interior of
        %the design.
        function y=getInteriorPoint(obj,x)
            y=0;
        end
        
    end    
        
    methods %The following functions can be implemented, but they can also be deleted.
    %If they are deleted the standard functions given in the abstract
    %class will be used.
    
        % design functions
        function u=evalNonlinDescrFuns(obj,x,y)
            %u=evalNonlinDescrFuns(x,y) evaluates the non linear 
            %describing functions. The output u is a vector where every 
            %entry corresponds to one constraint. If no such constraints 
            %are implemented, a empty vector of size 1x0 is returned.
                u=0;
        end  
        
        function [A,b]=getLinDescrFuns(obj,x)
            %[A,b]=getLinDescrFuns(x) returns the linear describing
            %functions A*y<=b.
            A=zeros(0,obj.dim);
            b=zeros(0,1);
        end
        
        function [lb,ub]=getBoundingBox(obj,x)
            %[lb,ub]=getBoundingBox(x) returns a bounding box of the design
            %fixed point x. lb and ub are rowvectors. If one variable yi is
            %unbounded, the bounds are -inf/inf.
            lb=-inf*ones(1,obj.dim);
            ub=inf*ones(1,obj.dim);
        end        
        
        %transformation function
        function y=evalTrafoFun(obj,x,z)
            %y=evalTrafoFun(x,z) evaluates the transformation function of 
            %the design at the points x and y
            y=z;
        end
        
        function z=evalInvTrafoFun(obj,x,y)    
            %z=evalInvTrafoFun(x,y) returns a preimage of the point y under 
            %the transformation function t for fixed parameters x.
            z=y;
        end
                
        %constraints on parameters
        function k=evalNonlinEqConstrsOnParams(obj,x)
            %h=evalNonlinEqConstrsOnParams(x) evaluates the non linear and
            %non semi-infinite equality constraints on the parameters x. 
            %The output h is a vector. Every entry corresponds to one 
            %constraint. If the function is not implemented, a empty vector 
            %of size 1x0 is returned.
            k=zeros(1,0);
        end
        function k=evalNonlinIneqConstrsOnParams(obj,x)
            %g=evalLevNonlinIneqConstrsOnParams(x) evaluates the non linear
            %and non semi-infinite inequality constraints on the parameters
            %x. The output g is a vector. Every entry corresponds to one 
            %constraint. If the function is not implemented, a empty vector 
            %of size 1x0 is returned. 
            k=zeros(1,0);
        end
        
    end
    
    %Derivatives can be implemented as described in the Documentation
    
end